summaryrefslogtreecommitdiffstats
path: root/kpovmodeler/pmgraphicalobjectedit.h
diff options
context:
space:
mode:
Diffstat (limited to 'kpovmodeler/pmgraphicalobjectedit.h')
-rw-r--r--kpovmodeler/pmgraphicalobjectedit.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/kpovmodeler/pmgraphicalobjectedit.h b/kpovmodeler/pmgraphicalobjectedit.h
index 36758f63..7564edae 100644
--- a/kpovmodeler/pmgraphicalobjectedit.h
+++ b/kpovmodeler/pmgraphicalobjectedit.h
@@ -41,9 +41,9 @@ class PMGraphicalObjectEdit : public PMDetailObjectEdit
typedef PMDetailObjectEdit Base;
public:
/**
* Creates a PMGraphicalObjectEdit with tqparent and name
*/
- PMGraphicalObjectEdit( TQWidget* tqparent, const char* name = 0 );
+ PMGraphicalObjectEdit( TQWidget* parent, const char* name = 0 );
/** */
virtual void displayObject( PMObject* o );
@@ -41,9 +41,9 @@ class PMGraphicalObjectEdit : public PMDetailObjectEdit
public:
/**
- * Creates a PMGraphicalObjectEdit with tqparent and name
+ * Creates a PMGraphicalObjectEdit with parent and name
*/